==> piwigo-2.5.3.zip: piwigo/language/br_FR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Posubl eo deoc\'h cheñch ho-unan kefluniadur PHP, ha adloc\'hañ Piwigo da c\'houde.';
$lang['Download the config file'] = 'Pellgargañ ar restr gefluniañ';
$lang['Try to configure PHP 5'] = 'Esaeit kefluniañ PHP 5';
$lang['Basic configuration'] = 'Kefluniadur diazez';
$lang['Database configuration'] = 'Kefluniadur an diaz roadennoù';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Un diskoulm all a zo eilañ an destenn eus boest a-us ha pegañ anezhañ da restr "local/config/database.inc.php" (Diwallit: ret eo lakaat e-barzh database.inc.php ar pezh a zo er framm-testenn, distro d\'al linenn ebet, hag arouezenn esaouiñ ebet)';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'An anavezer-mañ a vo gwellet gant an implijerien. Ret eo evit merañ al lec\'hienn.';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Ret eo dezhañ chom kuzhut, gantañ e vez digoret skramm ar mererezh.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'An implijerien a c\'hello dont e darempred gant merour al lec\'hienn gant ar bostel-mañ';
$lang['Admin configuration'] = 'Kefluniadur ar mererezh';
$lang['User'] = 'Implijer';
$lang['please enter your password again'] = 'Lakait ho ger-tremen adarre';
$lang['user password given by your host provider'] = 'ger-tremen roet gant ho pourvezer ostiz';
$lang['Password ']['confirm'] = 'Ger-tremen [evit kadarnaat]';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo n\'eo ket deuet a-benn da gefluniañ PHP 5.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo a c\'hell cheñch ho kefluniadur da PHP 5 en ur grouiñ pe kemmañ ur restr .htaccess.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'C\'hwitet eo krouadur ar restr gefluniañ local/config/database.inc.php.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Posubl eo deoc\'h pellgargañ ar restr gefluniañ, hag ezkargañ anezhañ da kavlec\'h local/config ho staliadur.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gourc\'hemennoù, echu eo staliadur Piwigo';
$lang['Installation'] = 'Staliadur';
$lang['Start Install'] = 'Kregiñ gant ar staliadur';
$lang['Welcome to your new installation of Piwigo!'] = 'Degemer mat en ho staliadur nevez Piwigo !';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Goulennit da skor ho pourvezer ostiz penaos e c\'hellit implij PHP 5.';
$lang['It appears your webhost is currently running PHP %s.'] = 'PHP %s a zo o labourat war hoc\'h ostiz.';
$lang['localhost or other, supplied by your host provider'] = 'localhost pe anv all, roet gant ho pourvezer ostiz';
$lang['also given by your host provider'] = 'roet gant ho pourvezer ostiz ivez';
$lang['user login given by your host provider'] = 'anv-implijer roet gant ho pourvezer ostiz';
$lang['Host'] = 'Ostiz';
$lang['Can\'t connect to server'] = 'Ne oa ket posubl kevreañ ouzh ar servijer';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Sikour ho peus ezhom? Savit ho goulennoù war <a href="%s">Forom Piwigo</a>.';
$lang['verification'] = 'gwiriadur';
$lang['Sorry!'] = 'Digarezit !';
$lang['PHP 5 is required'] = 'Ret eo kaout PHP 5';
$lang['Just another Piwigo gallery'] = 'Ur palier-luc\'hskeudennoù Piwigo all';
$lang['Hope to see you back soon.'] = 'Ken ar wech all !';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Lennit hor foromoù evit kaout sikour: %s';
$lang['enter a login for webmaster'] = 'Lakait anv implijer ar mestr-gwiad';
$lang['webmaster login can\'t contain characters \' or "'] = 'Arabat eo lakaat lizherennoù \' pe " e-barzh anv implijer ar mestr-gwiad';
$lang['Default gallery language'] = 'Yezh dre ziouer ar palier';
$lang['Welcome to my photo gallery'] = 'Degemer mat war ma palier-luc\'hskeudennoù';
$lang['Database table prefix'] = 'Rakger taolennoù an diaz roadennoù';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Ar rakger-mañ a vo ouzhpennet da anvioù taolennoù an diaz roadennoù (Gwelloc\'h e vo mererezh ho taolennoù)';
$lang['Database name'] = 'Anv an diaz roadennoù';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Kevreet mat ouzh ar servijer omp, met ne oa ket posubl kevreañ ouzh an diaz roadennoù.';
?>

==> piwigo-15.7.0.zip: piwigo/language/br_FR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Posubl eo deoc\'h cheñch ho-unan kefluniadur PHP, ha adloc\'hañ Piwigo da c\'houde.';
$lang['Download the config file'] = 'Pellgargañ ar restr gefluniañ';
$lang['Try to configure PHP 5'] = 'Esaeit kefluniañ PHP 5.2';
$lang['Basic configuration'] = 'Kefluniadur diazez';
$lang['Database configuration'] = 'Kefluniadur an diaz roadennoù';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Un diskoulm all a zo eilañ an destenn eus boest a-us ha pegañ anezhañ da restr "local/config/database.inc.php" (Diwallit: ret eo lakaat e-barzh database.inc.php ar pezh a zo er framm-testenn, distro d\'al linenn ebet, hag arouezenn esaouiñ ebet)';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'An anavezer-mañ a vo gwellet gant an implijerien. Ret eo evit merañ al lec\'hienn.';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Ret eo dezhañ chom kuzhut, gantañ e vez digoret skramm ar mererezh.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'An implijerien a c\'hello dont e darempred gant merour al lec\'hienn gant ar bostel-mañ';
$lang['Admin configuration'] = 'Kefluniadur ar mererezh';
$lang['User'] = 'Implijer';
$lang['please enter your password again'] = 'Lakait ho ger-tremen adarre';
$lang['user password given by your host provider'] = 'ger-tremen roet gant ho pourvezer ostiz';
$lang['Password ']['confirm'] = 'Ger-tremen [evit kadarnaat]';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo n\'eo ket deuet a-benn da gefluniañ PHP 5.2';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo a c\'hell cheñch ho kefluniadur da PHP 5.2 en ur grouiñ pe kemmañ ur restr .htaccess.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'C\'hwitet eo krouadur ar restr gefluniañ local/config/database.inc.php.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Posubl eo deoc\'h pellgargañ ar restr gefluniañ, hag ezkargañ anezhañ da kavlec\'h local/config ho staliadur.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gourc\'hemennoù, echu eo staliadur Piwigo';
$lang['Installation'] = 'Staliadur';
$lang['Start Install'] = 'Kregiñ gant ar staliadur';
$lang['Welcome to your new installation of Piwigo!'] = 'Degemer mat en ho staliadur nevez Piwigo !';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Goulennit da skor ho pourvezer ostiz penaos e c\'hellit implij PHP 5.2';
$lang['It appears your webhost is currently running PHP %s.'] = 'PHP %s a zo o labourat war hoc\'h ostiz.';
$lang['localhost or other, supplied by your host provider'] = 'localhost pe anv all, roet gant ho pourvezer ostiz';
$lang['also given by your host provider'] = 'roet gant ho pourvezer ostiz ivez';
$lang['user login given by your host provider'] = 'anv-implijer roet gant ho pourvezer ostiz';
$lang['Host'] = 'Ostiz';
$lang['Can\'t connect to server'] = 'Ne oa ket posubl kevreañ ouzh ar servijer';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Sikour ho peus ezhom? Savit ho goulennoù war <a href="%s">Forom Piwigo</a>.';
$lang['verification'] = 'gwiriadur';
$lang['Sorry!'] = 'Digarezit !';
$lang['PHP 5 is required'] = 'Ret eo kaout PHP 5.2';
$lang['Just another Piwigo gallery'] = 'Ur palier-luc\'hskeudennoù Piwigo all';
$lang['Hope to see you back soon.'] = 'Ken ar wech all !';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Lennit hor foromoù evit kaout sikour: %s';
$lang['enter a login for webmaster'] = 'Lakait anv implijer ar mestr-gwiad';
$lang['webmaster login can\'t contain characters \' or "'] = 'Arabat eo lakaat lizherennoù \' pe " e-barzh anv implijer ar mestr-gwiad';
$lang['Default gallery language'] = 'Yezh dre ziouer ar palier';
$lang['Welcome to my photo gallery'] = 'Degemer mat war ma palier-luc\'hskeudennoù';
$lang['Database table prefix'] = 'Rakger taolennoù an diaz roadennoù';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Ar rakger-mañ a vo ouzhpennet da anvioù taolennoù an diaz roadennoù (Gwelloc\'h e vo mererezh ho taolennoù)';
$lang['Database name'] = 'Anv an diaz roadennoù';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Kevreet mat ouzh ar servijer omp, met ne oa ket posubl kevreañ ouzh an diaz roadennoù.';
